View source: R/add_noise_gaussian.R
| add_noise_gaussian | R Documentation |
Add normal noise with mean 0 to predicted values with constant variance
add_noise_gaussian(
model,
new_data,
conf_model_data,
outcome_var,
col_schema,
pred,
variance = NULL,
rho = NULL,
sensitivity = NULL
)
model |
A |
new_data |
A data frame used to generate predictions |
conf_model_data |
A data frame for estimating the predictive model |
outcome_var |
A string name representing the outcome variable |
col_schema |
A list of column schema specifications for the new variable |
pred |
A vector of values predicted by the model |
variance |
Sampling variance for additive noise |
rho |
Alternative privacy loss budget prescribed by the Gaussian mechanism under rho-zero-concentrated differential privacy. |
sensitivity |
Alternative sample sensitivity prescribed by the Gaussian mechanism under rho-zero-concentrated differential privacy. |
A numeric vector with noise added to each prediction
add_noise_gaussian(
model = NULL,
new_data = NULL,
conf_model_data = NULL,
outcome_var = NULL,
col_schema = NULL,
pred = 1:100,
variance = 3
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.