add_sequence_manual: Add to visit sequence using a manual method

View source: R/visit_sequence_api.R

add_sequence_manualR Documentation

Add to visit sequence using a manual method

Description

Add to visit sequence using a manual method

Usage

add_sequence_manual(roadmap, ...)

Arguments

roadmap

A roadmap object.

...

tidy-select One or more unquoted expressions separated by commas. Variable names can be used as if they were positions in the data frame, so expressions like x:y can be used to select a range of variables.

Value

An updated roadmap object.

Examples


roadmap(
  conf_data = acs_conf_nw, 
  start_data = acs_start_nw
) |>
  add_sequence_manual(
    c("inctot", "hcovany", "empstat",  "classwkr",  "age",   "famsize",  
      "transit_time")
  )


tidysynthesis documentation built on March 17, 2026, 1:06 a.m.