| enforce_na | R Documentation |
Add missing values where values should be missing according to _NA variables
enforce_na(data)
data |
A synthetic data frame with _NA columns |
A synthetic data frame with _NA columns that converts values that are labelled missing in an _NA variable to missing in the corresponding variable
example_na_expanded <- expand_na(data = example_na)
enforce_na(data = example_na_expanded)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.