print.noise: Print the noise object to the console with formatting

View source: R/noise.R

print.noiseR Documentation

Print the noise object to the console with formatting

Description

Print the noise object to the console with formatting

Usage

## S3 method for class 'noise'
print(x, ...)

Arguments

x

A noise object

...

further arguments passed to or from other methods (not currently used).

Value

Invisibly returns the input noise object.

Examples


print(noise())


tidysynthesis documentation built on March 17, 2026, 1:06 a.m.