print.replicates: Print the replicates object to the console with formatting

View source: R/replicates.R

print.replicatesR Documentation

Print the replicates object to the console with formatting

Description

Print the replicates object to the console with formatting

Usage

## S3 method for class 'replicates'
print(x, ...)

Arguments

x

A replicates object

...

further arguments passed to or from other methods (not currently used).

Value

Invisibly returns the input replicates object.

Examples


rep <- replicates(
  start_data_replicates = 2,
  model_sample_replicates = 2,
  end_to_end_replicates = 2
)
  
print(rep)


tidysynthesis documentation built on March 17, 2026, 1:06 a.m.