print.schema: Print the schema object to the console with formatting

View source: R/schema.R

print.schemaR Documentation

Print the schema object to the console with formatting

Description

Print the schema object to the console with formatting

Usage

## S3 method for class 'schema'
print(x, ...)

Arguments

x

A schema object

...

further arguments passed to or from other methods (not currently used).

Value

Invisibly returns the input schema object.

Examples


# default inferred schema
schema1 <- schema(
  conf_data = acs_conf_nw,
  start_data = acs_start_nw
)

print(schema1)


tidysynthesis documentation built on March 17, 2026, 1:06 a.m.