print.synth_spec: Print the replicates object to the console with formatting

View source: R/synth_spec.R

print.synth_specR Documentation

Print the replicates object to the console with formatting

Description

Print the replicates object to the console with formatting

Usage

## S3 method for class 'synth_spec'
print(x, ...)

Arguments

x

A replicates object

...

further arguments passed to or from other methods (not currently used).

Value

A synth_spec object

Examples


synth_spec <- synth_spec()

print(synth_spec)


tidysynthesis documentation built on March 17, 2026, 1:06 a.m.