replicates: Create a replicates object

View source: R/replicates.R

replicatesR Documentation

Create a replicates object

Description

Create a replicates object

Usage

replicates(
  start_data_replicates = 1,
  model_sample_replicates = 1,
  end_to_end_replicates = 1
)

Arguments

start_data_replicates

The number of starting data replicates to use. Note that if no start_method is provided, all start data replicates will be identical.

model_sample_replicates

The number of replicates for the conditional modeling process, including modeling and sampling new synthetic values.

end_to_end_replicates

The number of replicates for the entire synthesis process, including all previously specified steps.

Value

A new replicates object.

Examples


replicates(
  start_data_replicates = 2,
  model_sample_replicates = 2,
  end_to_end_replicates = 2
)


tidysynthesis documentation built on March 17, 2026, 1:06 a.m.