roadmap: Create a roadmap

View source: R/roadmap.R

roadmapR Documentation

Create a roadmap

Description

A roadmap is a container object that aggregates information required to specify the order of operations for synthesis modeling and sampling steps.

Usage

roadmap(
  conf_data,
  start_data,
  start_method = NULL,
  schema = NULL,
  visit_sequence = NULL,
  replicates = NULL,
  constraints = NULL
)

Arguments

conf_data

A data.frame of confidential data.

start_data

A data.frame of starting data used to initialize the process.

start_method

An optional start_method object.

schema

An optional schema object.

visit_sequence

An optional visit_sequence object.

replicates

An optional replicates object.

constraints

An optional constraints object.

Details

Users initiate a roadmap object with conf_data and start_data. All other objects will either be completed with defaults or specified interactively via the provided API.

Value

A new roadmap object.

Examples

roadmap(
  conf_data = acs_conf_nw,
  start_data = acs_start_nw,
  start_method = start_method(
    start_func = start_resample, n = 1000
  )
) 



tidysynthesis documentation built on March 17, 2026, 1:06 a.m.