start_method: Create a 'start_method' object.

View source: R/start_method.R

start_methodR Documentation

Create a start_method object.

Description

A start_method gets executed prior to running a synthesis. This modifies the start_data, typically randomly, to provide greater disclosure risk protections.

Usage

start_method(start_func = NULL, ...)

Arguments

start_func

A function that accepts and returns a data.frame. If none provided .identity_start() is used.

...

Optional keyword arguments passed to start_func(...)

Value

A start_method object

Examples


# basic usage
start_method(start_func = start_resample)

# adjust the number of observations
start_method(
  start_func = start_resample,
  start_data = acs_start_nw,
  n = 10
)

# adjust the number of observations and use all combinations as support
start_method(
  start_func = start_resample,
  start_data = acs_start_nw,
  n = 10, 
  inv_noise_scale = 1,
  support = "all"
)


tidysynthesis documentation built on March 17, 2026, 1:06 a.m.