start_method_api: Add, update, or reset a start method within an existing...

start_method_apiR Documentation

Add, update, or reset a start method within an existing roadmap.

Description

Add, update, or reset a start method within an existing roadmap.

Usage

add_start_method(roadmap, start_method)

update_start_method(roadmap, ...)

remove_start_method(roadmap)

Arguments

roadmap

A roadmap object

start_method

A start_method object.

...

Optional named parameters passed to start_method()

Value

A new roadmap object.

A new roadmap object with added start_method.

A new roadmap object with updated start_method.

A new roadmap object with removed start_method.

Examples


rm <- roadmap( 
 conf_data = acs_conf_nw,
 start_data = acs_start_nw,
)

add_start_method(
  roadmap = rm,
  start_method = start_method()
)


rm <- roadmap( 
 conf_data = acs_conf_nw,
 start_data = acs_start_nw
)

update_start_method(
  roadmap = rm,
  start_method = start_method()
)

rm <- roadmap( 
 conf_data = acs_conf_nw,
 start_data = acs_start_nw,
 start_method = start_method()
)

remove_start_method(
  roadmap = rm
)


tidysynthesis documentation built on March 17, 2026, 1:06 a.m.