View source: R/start_resample.R
| start_resample | R Documentation |
Specify a resampling scheme for start_data
start_resample(
start_data,
n = NULL,
inv_noise_scale = NULL,
support = c("observed", "all")
)
start_data |
A |
n |
An optional integer sample size. If unspecified, |
inv_noise_scale |
An optional parameter to set randomized noise to the proportions
of records with different |
support |
A string that specifies the method of resampling from the |
A start_method object for resampling starting data
start_method(
start_func = start_resample, n = 1000
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.