| ks_distance | R Documentation |
Kolmogorov-Smirnov distance
ks_distance(data, ...)
## S3 method for class 'data.frame'
ks_distance(data, truth, estimate, na_rm = TRUE, case_weights = NULL, ...)
ks_distance_vec(truth, estimate, na_rm = TRUE, case_weights = NULL, ...)
data |
A |
... |
Not currently used. |
truth |
The column identifier for the true results (that is numeric).
This should be an unquoted column name although this argument is passed by
expression and supports quasiquotation (you can unquote column names). For
|
estimate |
The column identifier for the predicted results (that is
also numeric). As with truth this can be specified different ways but the
primary method is to use an unquoted variable name. For |
na_rm |
A |
case_weights |
This is a placeholder for now and will be added when case_weights are added to tidysynthesis. |
For ks_distance_vec(), a single numeric value (or NA).
A single numeric value (or NA).
A single numeric value (or NA).
ks1 <- data.frame(x = 1:100, y = 101:200)
ks_distance(data = ks1, truth = x, estimate = y)
ks1 <- data.frame(x = 1:100, y = 101:200)
ks_distance(data = ks1, truth = x, estimate = y)
ks1 <- data.frame(x = 1:100, y = 101:200)
ks_distance_vec(truth = ks1$x, estimate = ks1$y)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.