| print.replicates | R Documentation |
Print the replicates object to the console with formatting
## S3 method for class 'replicates'
print(x, ...)
x |
A |
... |
further arguments passed to or from other methods (not currently used). |
Invisibly returns the input replicates object.
rep <- replicates(
start_data_replicates = 2,
model_sample_replicates = 2,
end_to_end_replicates = 2
)
print(rep)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.