| print.schema | R Documentation |
Print the schema object to the console with formatting
## S3 method for class 'schema'
print(x, ...)
x |
A |
... |
further arguments passed to or from other methods (not currently used). |
Invisibly returns the input schema object.
# default inferred schema
schema1 <- schema(
conf_data = acs_conf_nw,
start_data = acs_start_nw
)
print(schema1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.