| print.synth_spec | R Documentation |
Print the replicates object to the console with formatting
## S3 method for class 'synth_spec'
print(x, ...)
x |
A |
... |
further arguments passed to or from other methods (not currently used). |
A synth_spec object
synth_spec <- synth_spec()
print(synth_spec)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.