| replicates | R Documentation |
Create a replicates object
replicates(
start_data_replicates = 1,
model_sample_replicates = 1,
end_to_end_replicates = 1
)
start_data_replicates |
The number of starting data replicates to use.
Note that if no |
model_sample_replicates |
The number of replicates for the conditional modeling process, including modeling and sampling new synthetic values. |
end_to_end_replicates |
The number of replicates for the entire synthesis process, including all previously specified steps. |
A new replicates object.
replicates(
start_data_replicates = 2,
model_sample_replicates = 2,
end_to_end_replicates = 2
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.