| roadmap | R Documentation |
A roadmap is a container object that aggregates information required to
specify the order of operations for synthesis modeling and sampling steps.
roadmap(
conf_data,
start_data,
start_method = NULL,
schema = NULL,
visit_sequence = NULL,
replicates = NULL,
constraints = NULL
)
conf_data |
A |
start_data |
A |
start_method |
An optional |
schema |
An optional |
visit_sequence |
An optional |
replicates |
An optional |
constraints |
An optional |
Users initiate a roadmap object with conf_data and start_data. All other
objects will either be completed with defaults or specified interactively via
the provided API.
A new roadmap object.
roadmap(
conf_data = acs_conf_nw,
start_data = acs_start_nw,
start_method = start_method(
start_func = start_resample, n = 1000
)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.